@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
 from plone import api
 from Products.CMFPlone.utils import safe_unicode
 
 import os
+import re
 
 
 ODS_FORMATS = (('ods', 'LibreOffice Calc (.ods)'),
@@ -57,10 +57,14 @@ def get_oo_server():
     )
 
 
-def get_oo_port():
-    return api.portal.get_registry_record(
-        'collective.documentgenerator.browser.controlpanel.IDocumentGeneratorControlPanelSchema.oo_port'
+def get_oo_port_list():
+    """
+    @return the LibreOffice ports numbers to use as a list of int.
+    """
+    oo_port_list = api.portal.get_registry_record(
+        'collective.documentgenerator.browser.controlpanel.IDocumentGeneratorControlPanelSchema.oo_port_list'
     )
+    return [int(port) for port in re.findall('([0-9]+)', oo_port_list)]
 
 
 def get_column_modifier():
@@ -110,10 +114,10 @@ def set_oo_server():
 
 def set_oo_port():
     """ Get environment value in buildout to define port """
-    oo_port = os.getenv('OO_PORT', DEFAULT_OO_PORT)
+    oo_port = unicode(os.getenv('OO_PORT', DEFAULT_OO_PORT))
     if oo_port:
         api.portal.set_registry_record('collective.documentgenerator.browser.controlpanel.'
-                                       'IDocumentGeneratorControlPanelSchema.oo_port', int(oo_port))
+                                       'IDocumentGeneratorControlPanelSchema.oo_port_list', oo_port)
 
 
 def set_uno_path():
