@@ -134,3 +134,21 @@ class TestVocabularies(BaseTest):
 
         voc = vocabulary(self.portal)
         self.assertListEqual([reusable_template_2.UID(), test_podtemplate.UID()], [t.value for t in voc])
+
+    def test_all_pod_templates_vocabulary(self):
+        """
+        Test the AllPODTemplate vocabulary.
+        """
+        voc_name = 'collective.documentgenerator.AllPODTemplateWithFile'
+        vocabulary = queryUtility(IVocabularyFactory, voc_name)
+        voc = vocabulary(self.portal)
+        self.assertEquals(len(voc), 9)
+
+    def test_all_value_in_all_pod_templates_vocabulary(self):
+        """
+        Test the 'all' value is in the AllPODTemplate vocabulary.
+        """
+        voc_name = 'collective.documentgenerator.AllPODTemplateWithFile'
+        vocabulary = queryUtility(IVocabularyFactory, voc_name)
+        voc = vocabulary(self.portal)
+        self.assertIn('all', voc)
